@@ -26,6 +26,8 @@ class EntrySerializer(serializers.BaseSerializer):
             'slug': instance.entry.get('slug'),
             'published': instance.entry.get('published'),
             'publish_date': instance.entry.get('publish_date'),
+            'should_publish_in_future': instance.entry.get('should_publish_in_future'),
+            'future_publish_date': instance.entry.get('future_publish_date'),
             'version': instance.entry.get('version'),
             'tags': instance.entry.get('tags'),
             'views': view_count,
@@ -43,6 +45,8 @@ class EntrySerializer(serializers.BaseSerializer):
         slug = data.get('slug')
         published = data.get('published')
         publish_date = data.get('publish_date')
+        should_publish_in_future = data.get('should_publish_in_future')
+        future_publish_date = data.get('future_publish_date')
         version = data.get('version')
         tags = data.get('tags')
 
@@ -55,6 +59,8 @@ class EntrySerializer(serializers.BaseSerializer):
             'slug': slug,
             'published': published,
             'publish_date': publish_date,
+            'should_publish_in_future': should_publish_in_future,
+            'future_publish_date': future_publish_date,
             'version': version,
             'tags': tags
         }
